# RealToxicityPrompts: Evaluating Neural Toxic Degeneration in Language Models

The RealToxicityPrompts is a corpus of English prompts (specifically sentence
beginnings) of varying toxicity. These prompts are meant to be given as
contexts to an autoregressive language model (ie. GPT-2) and used for
generating completions.

More details are presented in the original
[paper](https://api.semanticscholar.org/CorpusID:221878771).

